]> git.ipfire.org Git - people/ms/u-boot.git/commitdiff
env: Rename getenv_hex(), getenv_yesno(), getenv_ulong()
authorSimon Glass <sjg@chromium.org>
Thu, 3 Aug 2017 18:22:13 +0000 (12:22 -0600)
committerTom Rini <trini@konsulko.com>
Wed, 16 Aug 2017 12:30:32 +0000 (08:30 -0400)
We are now using an env_ prefix for environment functions. Rename these
for consistency. Also add function comments in common.h.

Suggested-by: Wolfgang Denk <wd@denx.de>
Signed-off-by: Simon Glass <sjg@chromium.org>
25 files changed:
arch/powerpc/cpu/mpc85xx/mp.c
board/BuR/brxre1/board.c
board/BuR/common/common.c
board/birdland/bav335x/board.c
board/gateworks/gw_ventana/gw_ventana_spl.c
board/gdsys/p1022/controlcenterd-id.c
board/tcl/sl50/board.c
board/ti/am335x/board.c
board/ti/am57xx/board.c
board/ti/dra7xx/evm.c
cmd/fdt.c
cmd/nvedit.c
cmd/source.c
cmd/trace.c
cmd/ximg.c
common/autoboot.c
common/board_f.c
common/board_r.c
common/bootm.c
drivers/bootcount/bootcount_env.c
env/common.c
include/common.h
lib/fdtdec.c
net/bootp.c
net/net.c

index 0addf8493c2577bbd6d07e66c383f2eb3e3f422c..2ea9f5c7be0fe4c4869776d0920c051046394b33 100644 (file)
@@ -31,7 +31,7 @@ u32 get_my_id()
 int hold_cores_in_reset(int verbose)
 {
        /* Default to no, overridden by 'y', 'yes', 'Y', 'Yes', or '1' */
-       if (getenv_yesno("mp_holdoff") == 1) {
+       if (env_get_yesno("mp_holdoff") == 1) {
                if (verbose) {
                        puts("Secondary cores are being held in reset.\n");
                        puts("See 'mp_holdoff' environment variable\n");
index cdbc93a8ec5732c94837be43ea8a222ec8f6090b..ca08f3cd90808e30572e0eb5f091c32123ffd407 100644 (file)
@@ -282,9 +282,9 @@ int board_late_init(void)
        snprintf(othbootargs, sizeof(othbootargs),
                 "u=vxWorksFTP pw=vxWorks o=0x%08x;0x%08x;0x%08x;0x%08x",
                 (unsigned int) gd->fb_base-0x20,
-                (u32)getenv_ulong("vx_memtop", 16, gd->fb_base-0x20),
-                (u32)getenv_ulong("vx_romfsbase", 16, 0),
-                (u32)getenv_ulong("vx_romfssize", 16, 0));
+                (u32)env_get_ulong("vx_memtop", 16, gd->fb_base-0x20),
+                (u32)env_get_ulong("vx_romfsbase", 16, 0),
+                (u32)env_get_ulong("vx_romfssize", 16, 0));
        env_set("othbootargs", othbootargs);
        /*
         * reset VBAR registers to its reset location, VxWorks 6.9.3.2 does
index 39a600b5c178011cd6a39f5e6a0311d117500f68..c1cd0100239333993a1e8ff2ab58e2937e39e8a2 100644 (file)
@@ -58,9 +58,9 @@ void lcdbacklight(int on)
        unsigned int bright = FDTPROP(PATHINF, "brightdef");
        unsigned int pwmfrq = FDTPROP(PATHINF, "brightfdim");
 #else
-       unsigned int driver = getenv_ulong("ds1_bright_drv", 16, 0UL);
-       unsigned int bright = getenv_ulong("ds1_bright_def", 10, 50);
-       unsigned int pwmfrq = getenv_ulong("ds1_pwmfreq", 10, ~0UL);
+       unsigned int driver = env_get_ulong("ds1_bright_drv", 16, 0UL);
+       unsigned int bright = env_get_ulong("ds1_bright_def", 10, 50);
+       unsigned int pwmfrq = env_get_ulong("ds1_pwmfreq", 10, ~0UL);
 #endif
        unsigned int tmp;
        struct gptimer *timerhw;
@@ -186,20 +186,20 @@ int load_lcdtiming(struct am335x_lcdpanel *panel)
        snprintf(buf, sizeof(buf), "fbcon=rotate:%d", panel_info.vl_rot);
        env_set("optargs_rot", buf);
 #else
-       pnltmp.hactive = getenv_ulong("ds1_hactive", 10, ~0UL);
-       pnltmp.vactive = getenv_ulong("ds1_vactive", 10, ~0UL);
-       pnltmp.bpp = getenv_ulong("ds1_bpp", 10, ~0UL);
-       pnltmp.hfp = getenv_ulong("ds1_hfp", 10, ~0UL);
-       pnltmp.hbp = getenv_ulong("ds1_hbp", 10, ~0UL);
-       pnltmp.hsw = getenv_ulong("ds1_hsw", 10, ~0UL);
-       pnltmp.vfp = getenv_ulong("ds1_vfp", 10, ~0UL);
-       pnltmp.vbp = getenv_ulong("ds1_vbp", 10, ~0UL);
-       pnltmp.vsw = getenv_ulong("ds1_vsw", 10, ~0UL);
-       pnltmp.pxl_clk_div = getenv_ulong("ds1_pxlclkdiv", 10, ~0UL);
-       pnltmp.pol = getenv_ulong("ds1_pol", 16, ~0UL);
-       pnltmp.pup_delay = getenv_ulong("ds1_pupdelay", 10, ~0UL);
-       pnltmp.pon_delay = getenv_ulong("ds1_tondelay", 10, ~0UL);
-       panel_info.vl_rot = getenv_ulong("ds1_rotation", 10, 0);
+       pnltmp.hactive = env_get_ulong("ds1_hactive", 10, ~0UL);
+       pnltmp.vactive = env_get_ulong("ds1_vactive", 10, ~0UL);
+       pnltmp.bpp = env_get_ulong("ds1_bpp", 10, ~0UL);
+       pnltmp.hfp = env_get_ulong("ds1_hfp", 10, ~0UL);
+       pnltmp.hbp = env_get_ulong("ds1_hbp", 10, ~0UL);
+       pnltmp.hsw = env_get_ulong("ds1_hsw", 10, ~0UL);
+       pnltmp.vfp = env_get_ulong("ds1_vfp", 10, ~0UL);
+       pnltmp.vbp = env_get_ulong("ds1_vbp", 10, ~0UL);
+       pnltmp.vsw = env_get_ulong("ds1_vsw", 10, ~0UL);
+       pnltmp.pxl_clk_div = env_get_ulong("ds1_pxlclkdiv", 10, ~0UL);
+       pnltmp.pol = env_get_ulong("ds1_pol", 16, ~0UL);
+       pnltmp.pup_delay = env_get_ulong("ds1_pupdelay", 10, ~0UL);
+       pnltmp.pon_delay = env_get_ulong("ds1_tondelay", 10, ~0UL);
+       panel_info.vl_rot = env_get_ulong("ds1_rotation", 10, 0);
 #endif
        if (
           ~0UL == (pnltmp.hactive) ||
@@ -251,7 +251,7 @@ static int load_devicetree(void)
 {
        int rc;
        loff_t dtbsize;
-       u32 dtbaddr = getenv_ulong("dtbaddr", 16, 0UL);
+       u32 dtbaddr = env_get_ulong("dtbaddr", 16, 0UL);
 
        if (dtbaddr == 0) {
                printf("%s: don't have a valid <dtbaddr> in env!\n", __func__);
@@ -375,7 +375,7 @@ int ft_board_setup(void *blob, bd_t *bd)
         * if no simplefb is requested through environment, we don't set up
         * one, instead we turn off backlight.
         */
-       if (getenv_ulong("simplefb", 10, 0) == 0) {
+       if (env_get_ulong("simplefb", 10, 0) == 0) {
                lcdbacklight(0);
                return 0;
        }
@@ -447,7 +447,7 @@ void lcdpower(int on)
        }
        pin = FDTPROP(PATHINF, "pwrpin");
 #else
-       pin = getenv_ulong("ds1_pwr", 16, ~0UL);
+       pin = env_get_ulong("ds1_pwr", 16, ~0UL);
 #endif
        if (pin == ~0UL) {
                puts("no pwrpin in dtb/env, cannot powerup display!\n");
index e174336e2c9c918dabfb697ebe18f6efc560c38b..f284568ec92098a3380c056df495ecffb1a5b08a 100644 (file)
@@ -163,7 +163,7 @@ int spl_start_uboot(void)
 #ifdef CONFIG_SPL_ENV_SUPPORT
        env_init();
        env_load();
-       if (getenv_yesno("boot_os") != 1)
+       if (env_get_yesno("boot_os") != 1)
                return 1;
 #endif
 
index feea228b3d61a3ebe39a367904aed72b4b6346c1..9524da7daf392166f55b9d7f5b49d526e858ccb9 100644 (file)
@@ -692,7 +692,7 @@ int spl_start_uboot(void)
        env_init();
        env_load();
        debug("boot_os=%s\n", env_get("boot_os"));
-       if (getenv_yesno("boot_os") == 1)
+       if (env_get_yesno("boot_os") == 1)
                ret = 0;
 #else
        /* use i2c-0:0x50:0x00 for falcon boot mode (0=linux, else uboot) */
index 61c030a4588c5b566c11b2bae26c3f1917b13787..1813a58e60bf62e7ce805df9be76bb1097c9f633 100644 (file)
@@ -217,7 +217,7 @@ static u8 *get_2nd_stage_bl_location(ulong target_addr)
 {
        ulong addr;
 #ifdef CCDM_SECOND_STAGE
-       addr = getenv_ulong("loadaddr", 16, CONFIG_LOADADDR);
+       addr = env_get_ulong("loadaddr", 16, CONFIG_LOADADDR);
 #else
        addr = target_addr;
 #endif
@@ -235,7 +235,7 @@ static u8 *get_image_location(void)
 {
        ulong addr;
        /* TODO use other area? */
-       addr = getenv_ulong("loadaddr", 16, CONFIG_LOADADDR);
+       addr = env_get_ulong("loadaddr", 16, CONFIG_LOADADDR);
        return (u8 *)(addr);
 }
 #endif
index 08af279751ac5e1fdce0c8cb38757adffa434fc0..f79bb9dcdd5f76235b4697aa9ce13f429c9af84c 100644 (file)
@@ -77,7 +77,7 @@ int spl_start_uboot(void)
 #ifdef CONFIG_SPL_ENV_SUPPORT
        env_init();
        env_load();
-       if (getenv_yesno("boot_os") != 1)
+       if (env_get_yesno("boot_os") != 1)
                return 1;
 #endif
 
index ab835856e5fee3352f723d74e4651e539d2f40e7..1a52bffc002294fbdeee04e509565cef33c183d1 100644 (file)
@@ -250,7 +250,7 @@ int spl_start_uboot(void)
 #ifdef CONFIG_SPL_ENV_SUPPORT
        env_init();
        env_load();
-       if (getenv_yesno("boot_os") != 1)
+       if (env_get_yesno("boot_os") != 1)
                return 1;
 #endif
 
index 7bcbc31042f2c05cc01efc73eab970b13f3c7112..7e7056cf71c5012150a1328a0cd8defee3fd6871 100644 (file)
@@ -743,7 +743,7 @@ int spl_start_uboot(void)
 #ifdef CONFIG_SPL_ENV_SUPPORT
        env_init();
        env_load();
-       if (getenv_yesno("boot_os") != 1)
+       if (env_get_yesno("boot_os") != 1)
                return 1;
 #endif
 
index bdbf7f67969438d7dd4a90e2fce4d2d8d4cf6234..93d3d0b54ebab0c9b6cd63fa1cf0674528f939d8 100644 (file)
@@ -826,7 +826,7 @@ int spl_start_uboot(void)
 #ifdef CONFIG_SPL_ENV_SUPPORT
        env_init();
        env_load();
-       if (getenv_yesno("boot_os") != 1)
+       if (env_get_yesno("boot_os") != 1)
                return 1;
 #endif
 
index eb01a889ad2e585ccbf2ab5e91261b547dfa93c7..118613f405169c82d70f5d50c76dec1341761200 100644 (file)
--- a/net/net.c
+++ b/net/net.c
@@ -329,7 +329,7 @@ void net_auto_load(void)
                return;
        }
 #endif
-       if (getenv_yesno("autoload") == 0) {
+       if (env_get_yesno("autoload") == 0) {
                /*
                 * Just use BOOTP/RARP to configure system;
                 * Do not use TFTP to load the bootfile.
--- a/cmd/fdt.c
+++ b/cmd/fdt.c
@@ -111,7 +111,7 @@ static int do_fdt(cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
                                return 1;
                        printf("The address of the fdt is %#08lx\n",
                               control ? (ulong)map_to_sysmem(blob) :
-                                       getenv_hex("fdtaddr", 0));
+                                       env_get_hex("fdtaddr", 0));
                        return 0;
                }
 
index 0468a4b7e9abba393e8ff402897bf9c52e4bee0f..4033d90c8e2dd043384b93ba005fd15e1e93447c 100644 (file)
@@ -327,7 +327,7 @@ int env_set_hex(const char *varname, ulong value)
        return env_set(varname, str);
 }
 
-ulong getenv_hex(const char *varname, ulong default_val)
+ulong env_get_hex(const char *varname, ulong default_val)
 {
        const char *s;
        ulong value;
@@ -690,7 +690,7 @@ int env_get_f(const char *name, char *buf, unsigned len)
  *                     found
  * @return the decoded value, or default_val if not found
  */
-ulong getenv_ulong(const char *name, int base, ulong default_val)
+ulong env_get_ulong(const char *name, int base, ulong default_val)
 {
        /*
         * We can use env_get() here, even before relocation, since the
index 177f86bb54d946e9f32ab4e57460ae3403c778a6..a9831b6608581661c8f274abec93a283f679bc01 100644 (file)
@@ -40,7 +40,7 @@ source (ulong addr, const char *fit_uname)
        size_t          fit_len;
 #endif
 
-       verify = getenv_yesno ("verify");
+       verify = env_get_yesno("verify");
 
        buf = map_sysmem(addr, 0);
        switch (genimg_get_format(buf)) {
index e6c08e4ba564598ff8de2263162a27f5f4d824e4..a0a7dd1995983445da4bd82ad0b2cbf5d63a355b 100644 (file)
@@ -16,10 +16,10 @@ static int get_args(int argc, char * const argv[], char **buff,
        if (argc < 2)
                return -1;
        if (argc < 4) {
-               *buff_size = getenv_ulong("profsize", 16, 0);
-               *buff = map_sysmem(getenv_ulong("profbase", 16, 0),
+               *buff_size = env_get_ulong("profsize", 16, 0);
+               *buff = map_sysmem(env_get_ulong("profbase", 16, 0),
                                   *buff_size);
-               *buff_ptr = getenv_ulong("profoffset", 16, 0);
+               *buff_ptr = env_get_ulong("profoffset", 16, 0);
        } else {
                *buff_size = simple_strtoul(argv[3], NULL, 16);
                *buff = map_sysmem(simple_strtoul(argv[2], NULL, 16),
index 50dc00e4f80ba8d63fd874057c5131e16a189f0d..21b5c377218331012e39e10be13ec74a324cc00b 100644 (file)
@@ -52,7 +52,7 @@ do_imgextract(cmd_tbl_t * cmdtp, int flag, int argc, char * const argv[])
 #endif
        uint8_t         comp;
 
-       verify = getenv_yesno("verify");
+       verify = env_get_yesno("verify");
 
        if (argc > 1) {
                addr = simple_strtoul(argv[1], NULL, 16);
index 35c1e972c6593e0998f1ff92ab56cd371d4042b4..a0118650287e08e12e979dffc3367acdb8bfc01c 100644 (file)
@@ -301,7 +301,7 @@ const char *bootdelay_process(void)
        bootcount++;
        bootcount_store(bootcount);
        env_set_ulong("bootcount", bootcount);
-       bootlimit = getenv_ulong("bootlimit", 10, 0);
+       bootlimit = env_get_ulong("bootlimit", 10, 0);
 #endif /* CONFIG_BOOTCOUNT_LIMIT */
 
        s = env_get("bootdelay");
index 5915e500ae8532ebfda77ce2f33abfec709dea4a..de5f398a0b9f2ba0f918089b9e78a85df3db1304 100644 (file)
@@ -118,7 +118,7 @@ __weak void board_add_ram_info(int use_default)
 
 static int init_baud_rate(void)
 {
-       gd->baudrate = getenv_ulong("baudrate", 10, CONFIG_BAUDRATE);
+       gd->baudrate = env_get_ulong("baudrate", 10, CONFIG_BAUDRATE);
        return 0;
 }
 
@@ -324,7 +324,7 @@ static int reserve_pram(void)
 {
        ulong reg;
 
-       reg = getenv_ulong("pram", 10, CONFIG_PRAM);
+       reg = env_get_ulong("pram", 10, CONFIG_PRAM);
        gd->relocaddr -= (reg << 10);           /* size is in kB */
        debug("Reserving %ldk for protected RAM at %08lx\n", reg,
              gd->relocaddr);
index 016dc0262c9c2f437c2b5c1a8709620ddbe87106..c659714ca2d6c8f42547fa12ad83c59c8c8340fe 100644 (file)
@@ -372,7 +372,7 @@ static int initr_flash(void)
        *
        * NOTE: Maybe we should add some WATCHDOG_RESET()? XXX
        */
-       if (getenv_yesno("flashchecksum") == 1) {
+       if (env_get_yesno("flashchecksum") == 1) {
                printf("  CRC: %08X", crc32(0,
                        (const unsigned char *) CONFIG_SYS_FLASH_BASE,
                        flash_size));
@@ -490,7 +490,7 @@ static int initr_env(void)
 #endif
 
        /* Initialize from environment */
-       load_addr = getenv_ulong("loadaddr", 16, load_addr);
+       load_addr = env_get_ulong("loadaddr", 16, load_addr);
 
        return 0;
 }
@@ -651,7 +651,7 @@ int initr_mem(void)
        char memsz[32];
 
 # ifdef CONFIG_PRAM
-       pram = getenv_ulong("pram", 10, CONFIG_PRAM);
+       pram = env_get_ulong("pram", 10, CONFIG_PRAM);
 # endif
 # if defined(CONFIG_LOGBUFFER) && !defined(CONFIG_ALT_LB_ADDR)
        /* Also take the logbuffer into account (pram is in kB) */
index 0c380e742f3f24c2c4fdc95bdaa22f9bcb5bbebc..08563540670c4349d3915091702ffcaa9eb10a34 100644 (file)
@@ -72,7 +72,7 @@ static int bootm_start(cmd_tbl_t *cmdtp, int flag, int argc,
                       char * const argv[])
 {
        memset((void *)&images, 0, sizeof(images));
-       images.verify = getenv_yesno("verify");
+       images.verify = env_get_yesno("verify");
 
        boot_start_lmb(&images);
 
@@ -534,7 +534,7 @@ static void fixup_silent_linux(void)
         *      yes - we always fixup
         *      unset - we rely on the console silent flag
         */
-       want_silent = getenv_yesno("silent_linux");
+       want_silent = env_get_yesno("silent_linux");
        if (want_silent == 0)
                return;
        else if (want_silent == -1 && !(gd->flags & GD_FLG_SILENT))
index ec5f9426760242401c9d23f11556d49aeb69fb28..c3618d3a596b624fb382fda0e134b0d663720468 100644 (file)
@@ -10,7 +10,7 @@
 
 void bootcount_store(ulong a)
 {
-       int upgrade_available = getenv_ulong("upgrade_available", 10, 0);
+       int upgrade_available = env_get_ulong("upgrade_available", 10, 0);
 
        if (upgrade_available) {
                env_set_ulong("bootcount", a);
@@ -20,11 +20,11 @@ void bootcount_store(ulong a)
 
 ulong bootcount_load(void)
 {
-       int upgrade_available = getenv_ulong("upgrade_available", 10, 0);
+       int upgrade_available = env_get_ulong("upgrade_available", 10, 0);
        ulong val = 0;
 
        if (upgrade_available)
-               val = getenv_ulong("bootcount", 10, 0);
+               val = env_get_ulong("bootcount", 10, 0);
 
        return val;
 }
index 110323ecea7cc6f67163708a326c2d54c9397cb9..71613aa9deb385a4dec2543d95c8d5757741bb67 100644 (file)
@@ -31,7 +31,7 @@ struct hsearch_data env_htab = {
  * Read an environment variable as a boolean
  * Return -1 if variable does not exist (default to true)
  */
-int getenv_yesno(const char *var)
+int env_get_yesno(const char *var)
 {
        char *s = env_get(var);
 
index 7574ca754c2f552f5bd5fb99e231a7a4bd93ed89..eb44c9ef4231c47dbdd8e5cd78812524694d2c86 100644 (file)
@@ -335,10 +335,21 @@ char *env_get(const char *varname);
  */
 int env_get_f(const char *name, char *buf, unsigned len);
 
-ulong getenv_ulong(const char *name, int base, ulong default_val);
+/**
+ * env_get_ulong() - Return an environment variable as an integer value
+ *
+ * Most U-Boot environment variables store hex values. For those which store
+ * (e.g.) base-10 integers, this function can be used to read the value.
+ *
+ * @name:      Variable to look up
+ * @base:      Base to use (e.g. 10 for base 10, 2 for binary)
+ * @default_val: Default value to return if no value is found
+ * @return the value found, or @default_val if none
+ */
+ulong env_get_ulong(const char *name, int base, ulong default_val);
 
 /**
* getenv_hex() - Return an environment variable as a hex value
  *
  * Decode an environment as a hex number (it may or may not have a 0x
  * prefix). If the environment variable cannot be found, or does not start
@@ -347,13 +358,13 @@ ulong getenv_ulong(const char *name, int base, ulong default_val);
  * @varname:           Variable to decode
  * @default_val:       Value to return on error
  */
-ulong getenv_hex(const char *varname, ulong default_val);
+ulong env_get_hex(const char *varname, ulong default_val);
 
 /*
  * Read an environment variable as a boolean
  * Return -1 if variable does not exist (default to true)
  */
-int getenv_yesno(const char *var);
+int env_get_yesno(const char *var);
 
 /**
  * env_set() - set an environment variable
index d2dbd0f122ea1b358306586ea3613ae263dc0c3c..107a892e79c274e0b6e2c44cf2516aef7d469a1e 100644 (file)
@@ -1240,7 +1240,7 @@ int fdtdec_setup(void)
 # endif
 # ifndef CONFIG_SPL_BUILD
        /* Allow the early environment to override the fdt address */
-       gd->fdt_blob = (void *)getenv_ulong("fdtcontroladdr", 16,
+       gd->fdt_blob = (void *)env_get_ulong("fdtcontroladdr", 16,
                                                (uintptr_t)gd->fdt_blob);
 # endif
 #endif
index 6c869ef8560b45a83bdf0c7e0932567b6122b708..73370a13fe7de813f9bb6ec7ff9daad7982b9047 100644 (file)
@@ -504,7 +504,7 @@ static int dhcp_extended(u8 *e, int message_type, struct in_addr server_ip,
 #endif
 
        if (env_get("bootp_arch"))
-               clientarch = getenv_ulong("bootp_arch", 16, clientarch);
+               clientarch = env_get_ulong("bootp_arch", 16, clientarch);
 
        if (clientarch > 0) {
                *e++ = 93;      /* Client System Architecture */
@@ -335,10 +335,21 @@ char *env_get(const char *varname);
 
 /**
- * getenv_hex() - Return an environment variable as a hex value
+ * env_get_hex() - Return an environment variable as a hex value
  *
  * Decode an environment as a hex number (it may or may not have a 0x
index 4f82a7e46b204c507c550ea2dc756b6814d14e5f..0b876913e35fe89a74d02e76348fe515cec1a2d9 100644 (file)